from dorothy.lib import xjson


class ApiError(Exception):
    def __init__(self, code, message):
        self.code = code
        self.message = message

    def __str__(self):
        return xjson.dumps(dict(code=self.code, error=self.message))


class SettingsError(Exception):
    pass


class NotFoundError(Exception):
    pass